@@ -3,9 +3,9 @@ package Acme::CPANModules::PortedFrom::Python;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-31'; # DATE
+our $DATE = '2024-01-15'; # DATE
 our $DIST = 'Acme-CPANModules-PortedFrom-Python'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 our $LIST = {
     summary => "List of modules/applications that are ported from (or inspired by) ".
@@ -62,6 +62,9 @@ required."
 
 _
         },
+        {
+            module => 'Sub::Fp',
+        },
     ],
 };
 
@@ -80,7 +83,7 @@ Acme::CPANModules::PortedFrom::Python - List of modules/applications that are po
 
 =head1 VERSION
 
-This document describes version 0.008 of Acme::CPANModules::PortedFrom::Python (from Perl distribution Acme-CPANModules-PortedFrom-Python), released on 2023-10-31.
+This document describes version 0.009 of Acme::CPANModules::PortedFrom::Python (from Perl distribution Acme-CPANModules-PortedFrom-Python), released on 2024-01-15.
 
 =head1 DESCRIPTION
 
@@ -125,6 +128,10 @@ Perl. Dash makes building analytical web applications very easy. No JavaScript
 required."
 
 
+=item L<Sub::Fp>
+
+Author: L<ODDTUPLE|https://metacpan.org/author/ODDTUPLE>
+
 =back
 
 =head1 FAQ
@@ -203,7 +210,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022, 2021, 2020, 2018 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2022, 2021, 2020, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
